same_grade_scale

Function same_grade_scale 

pub fn same_grade_scale(left: &str, right: &str) -> bool
Whether two scale ids name the same scale. The pass/fail id has two spellings in circulation, so comparing the strings would call an attainment we ourselves registered a different scale.